from django.core.paginator import Paginator, PageNotAnInteger, EmptyPage

from inspect_report.models import Seat


def page_with_seat_name(all_objects, page, page_size, agent=False):
    paginator = Paginator(all_objects, page_size)
    total_count = paginator.count
    try:
        objects = paginator.page(page)
    except PageNotAnInteger:
        objects = paginator.page(1)
    except EmptyPage:
        objects = paginator.page(paginator.num_pages)

    if agent:
        objects = set_object_seat_name(objects)
    return total_count, objects


def set_object_seat_name(objects):
    agent_names = [x['agentName'] for x in objects]
    seats_code_name_list = Seat.objects.filter(code__in=agent_names).values('code', 'name')
    seats_code_name = dict()
    for seat_code_name in seats_code_name_list:
        seats_code_name[seat_code_name['code']] = seat_code_name['name']
    for object_dict in objects:
        object_dict['seatName'] = seats_code_name.get(object_dict['agentName'], object_dict['agentName'])

    return objects
